summaryrefslogtreecommitdiffstats
path: root/source/slang/slang-ir-specialize-resources.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'source/slang/slang-ir-specialize-resources.cpp')
-rw-r--r--source/slang/slang-ir-specialize-resources.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/source/slang/slang-ir-specialize-resources.cpp b/source/slang/slang-ir-specialize-resources.cpp
index 0ac08236f..e8a13b2e7 100644
--- a/source/slang/slang-ir-specialize-resources.cpp
+++ b/source/slang/slang-ir-specialize-resources.cpp
@@ -349,7 +349,7 @@ struct ResourceOutputSpecializationPass
for (auto param : func->getParams())
{
auto paramType = param->getDataType();
- auto outType = as<IROutTypeBase>(paramType);
+ auto outType = as<IROutParamTypeBase>(paramType);
if (!outType)
continue;
auto valueType = outType->getValueType();
@@ -803,11 +803,11 @@ struct ResourceOutputSpecializationPass
FuncInfo& ioFuncInfo)
{
// We only want to specialize in the case where the parameter
// is an `out` or `inout` (both inherit from `IROutTypeBase`),
// and the pointed-to type is a resource.
//
auto paramType = param->getDataType();
- auto outType = as<IROutTypeBase>(paramType);
+ auto outType = as<IROutParamTypeBase>(paramType);
if (!outType)
return SpecializeFuncResult::Ok;
auto valueType = outType->getValueType();
@@ -835,7 +835,7 @@ struct ResourceOutputSpecializationPass
//
IRVar* newVar = bodyBuilder.emitVar(valueType);
- if (as<IRInOutType>(outType))
+ if (as<IRBorrowInOutParamType>(outType))
{
// If the parameter is an `inout` rather than just
// an `out`, then we still need a parameter to
@@ -803,11 +803,11 @@ struct ResourceOutputSpecializationPass
{
// We only want to specialize in the case where the parameter
- // is an `out` or `inout` (both inherit from `IROutTypeBase`),
+ // is an `out` or `inout` (both inherit from `IROutParamTypeBase`),
// and the pointed-to type is a resource.
//